=======
History
=======

0.2.0 (2020-06-06)
------------------

* Default to give the first emoji after searching some keywords.
* Add shortcodes to some emojis and beautify the output.

0.1.0 (2020-06-05)
------------------

* First release on PyPI.
